==> lclint_2.1b-1.tar.gz: lclint-2.1b/src/Headers/sRefSetList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994, 1995, 1996.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. This code may not be re-distributed or modified
**        without permission from MIT (contact 
**        lclint-request@larch.lcs.mit.edu.)  
**
**        Modification and re-distribution are encouraged,
**        but we want to keep track of changes and
**        distribution sites.
*/
# ifndef sRefSetLIST_H
# define sRefSetLIST_H

typedef /*@dependent@*/ sRefSet d_sRefSet;

abst_typedef /*@null@*/ struct _sRefSetList
{
  int      nelements;
  int      nspace;
  /*@reldef@*/ /*@relnull@*/ d_sRefSet *elements;
} *sRefSetList ;

/*@iter sRefSetList_elements (sef sRefSetList x, yield exposed sRefSet el); @*/
# define sRefSetList_elements(x, m_el) \
   { if (sRefSetList_isDefined (x)) { \
     int m_ind; sRefSet *m_elements = &((x)->elements[0]); \
     for (m_ind = 0 ; m_ind < (x)->nelements; m_ind++) \
       { sRefSet m_el = *(m_elements++); 

# define end_sRefSetList_elements }}}

/*@constant null sRefSetList sRefSetList_undefined; @*/
# define sRefSetList_undefined  ((sRefSetList) NULL)

extern /*@falsenull@*/ bool sRefSetList_isDefined (sRefSetList s);
# define sRefSetList_isDefined(s) ((s) != sRefSetList_undefined)

extern /*@unused@*/ /*@truenull@*/ bool sRefSetList_isUndefined (sRefSetList s);
# define sRefSetList_isUndefined(s) ((s) == sRefSetList_undefined)

extern sRefSetList 
  sRefSetList_add (/*@returned@*/ sRefSetList s, /*@exposed@*/ sRefSet el)
  /*@modifies s@*/ ;

extern void sRefSetList_free (/*@only@*/ sRefSetList s);
extern void sRefSetList_clear (sRefSetList s);

/*@constant int sRefSetListBASESIZE;@*/
# define sRefSetListBASESIZE MIDBASESIZE

# else
# error "Multiple include"
# endif

==> lclint_2.4b.orig.tar.gz: lclint-2.4b/src/Headers/sRefSetList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994-1998.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. Works derived from this code are not distributed for
**        commercial gain without explicit permission from MIT 
**        (for permission contact lclint-request@sds.lcs.mit.edu).
*/
# ifndef sRefSetLIST_H
# define sRefSetLIST_H

typedef /*@dependent@*/ sRefSet d_sRefSet;

abst_typedef /*@null@*/ struct _sRefSetList
{
  int      nelements;
  int      nspace;
  /*@reldef@*/ /*@relnull@*/ d_sRefSet *elements;
} *sRefSetList ;

/*@iter sRefSetList_elements (sef sRefSetList x, yield exposed sRefSet el); @*/
# define sRefSetList_elements(x, m_el) \
   { if (sRefSetList_isDefined (x)) { \
     int m_ind; sRefSet *m_elements = &((x)->elements[0]); \
     for (m_ind = 0 ; m_ind < (x)->nelements; m_ind++) \
       { sRefSet m_el = *(m_elements++); 

# define end_sRefSetList_elements }}}

/*@constant null sRefSetList sRefSetList_undefined; @*/
# define sRefSetList_undefined  ((sRefSetList) NULL)

extern /*@falsenull@*/ bool sRefSetList_isDefined (sRefSetList p_s);
# define sRefSetList_isDefined(s) ((s) != sRefSetList_undefined)

extern /*@unused@*/ /*@truenull@*/ bool sRefSetList_isUndefined (sRefSetList p_s);
# define sRefSetList_isUndefined(s) ((s) == sRefSetList_undefined)

extern sRefSetList 
  sRefSetList_add (/*@returned@*/ sRefSetList p_s, /*@exposed@*/ sRefSet p_el)
  /*@modifies p_s@*/ ;

extern void sRefSetList_free (/*@only@*/ sRefSetList p_s);
extern void sRefSetList_clear (sRefSetList p_s);

/*@constant int sRefSetListBASESIZE;@*/
# define sRefSetListBASESIZE MIDBASESIZE

# else
# error "Multiple include"
# endif
